ActorAndObjectProperties

Struct ActorAndObjectProperties 

pub struct ActorAndObjectProperties {
    pub actor: ActorAndObjectPropertiesActorEnum,
    pub object: ActorAndObjectPropertiesObjectEnum,
}
Struct with actor and object properties

Fields

actor: ActorAndObjectPropertiesActorEnum

Describes one or more entities that either performed or are expected to perform the activity.

Any single activity can have multiple actors. The actor MAY be specified using an indirect Link.

  • Range: Object | Link
  • Functional: false
object: ActorAndObjectPropertiesObjectEnum

When used within an Activity, describes the direct object of the activity.

For instance, in the activity “John added a movie to his wishlist”, the object of the activity is the movie added.

  • Range: Object | Link
  • Functional: false

Implementations

Source

impl ActorAndObjectProperties

pub fn get_actor_xsd_any_uri(&self) -> Option<&XsdAnyUri>

Get the actor as a XsdAnyUri

This returns None if

  • There is more than one value present
  • The requested type is not the stored type
pub fn set_actor_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set actor with a value that can be converted into XsdAnyUri

pub fn get_many_actor_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>

Get actor as a vec of &XsdAnyUris

This returns None if

  • There is only one value present

The returned vec will be empty if no values match the requested type, but values are present.

pub fn set_many_actor_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set actor from a vec of items that can be converted into XsdAnyUris

pub fn get_actor_base_box(&self) -> Option<&BaseBox>

Get the actor as a BaseBox

This returns None if

  • There is more than one value present
  • The requested type is not the stored type
pub fn set_actor_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set actor with a value that can be converted into BaseBox

pub fn get_many_actor_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>

Get actor as a vec of &BaseBoxs

This returns None if

  • There is only one value present

The returned vec will be empty if no values match the requested type, but values are present.

pub fn set_many_actor_base_boxes<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set actor from a vec of items that can be converted into BaseBoxs

pub fn get_object_xsd_any_uri(&self) -> Option<&XsdAnyUri>

Get the object as a XsdAnyUri

This returns None if

  • There is more than one value present
  • The requested type is not the stored type
pub fn set_object_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set object with a value that can be converted into XsdAnyUri

pub fn get_many_object_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>

Get object as a vec of &XsdAnyUris

This returns None if

  • There is only one value present

The returned vec will be empty if no values match the requested type, but values are present.

pub fn set_many_object_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set object from a vec of items that can be converted into XsdAnyUris

pub fn get_object_base_box(&self) -> Option<&BaseBox>

Get the object as a BaseBox

This returns None if

  • There is more than one value present
  • The requested type is not the stored type
pub fn set_object_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set object with a value that can be converted into BaseBox

pub fn get_many_object_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>

Get object as a vec of &BaseBoxs

This returns None if

  • There is only one value present

The returned vec will be empty if no values match the requested type, but values are present.

pub fn set_many_object_base_boxes<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set object from a vec of items that can be converted into BaseBoxs