QuestionProperties

Struct QuestionProperties 

pub struct QuestionProperties {
    pub one_of: Option<QuestionPropertiesOneOfEnum>,
    pub any_of: Option<QuestionPropertiesAnyOfEnum>,
}
Properties for the Question activity

Fields

one_of: Option<QuestionPropertiesOneOfEnum>

Identifies an exclusive option for a Question.

Use of one_of implies that the Question can have only a single answer. To indicate that a Question can have multiple answers, use any_of.

  • Range: Object | Link
  • Functional: false
any_of: Option<QuestionPropertiesAnyOfEnum>

Identifies an inclusive option for a Question.

Use of any_of implies that the Question can have multiple answers. To indicate that a Question can have only one answer, use one_of.

  • Range: Object | Link
  • Functional: false

Implementations

Source

impl QuestionProperties

pub fn get_one_of_xsd_any_uri(&self) -> Option<&XsdAnyUri>

Get one_of as a XsdAnyUri

This returns None if

  • There is no value present
  • There is more than one value present
  • The requested type is not stored type
pub fn set_one_of_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set one_of from a value that can be converted into XsdAnyUri

pub fn get_many_one_of_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>

Get one_of as a slice of QuestionPropertiesOneOfTermEnums

This returns None if

  • There is no value present
  • There is only one value present
pub fn set_many_one_of_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set one_of from a vec of items that can be converted into XsdAnyUris

pub fn get_one_of_base_box(&self) -> Option<&BaseBox>

Get one_of as a BaseBox

This returns None if

  • There is no value present
  • There is more than one value present
  • The requested type is not stored type
pub fn set_one_of_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set one_of from a value that can be converted into BaseBox

pub fn get_many_one_of_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>

Get one_of as a slice of QuestionPropertiesOneOfTermEnums

This returns None if

  • There is no value present
  • There is only one value present
pub fn set_many_one_of_base_boxes<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set one_of from a vec of items that can be converted into BaseBoxs

pub fn delete_one_of(&mut self) -> &mut Self

Set the one_of field to None

pub fn get_any_of_xsd_any_uri(&self) -> Option<&XsdAnyUri>

Get any_of as a XsdAnyUri

This returns None if

  • There is no value present
  • There is more than one value present
  • The requested type is not stored type
pub fn set_any_of_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set any_of from a value that can be converted into XsdAnyUri

pub fn get_many_any_of_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>

Get any_of as a slice of QuestionPropertiesAnyOfTermEnums

This returns None if

  • There is no value present
  • There is only one value present
pub fn set_many_any_of_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
where T: TryInto<XsdAnyUri>,

Set any_of from a vec of items that can be converted into XsdAnyUris

pub fn get_any_of_base_box(&self) -> Option<&BaseBox>

Get any_of as a BaseBox

This returns None if

  • There is no value present
  • There is more than one value present
  • The requested type is not stored type
pub fn set_any_of_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set any_of from a value that can be converted into BaseBox

pub fn get_many_any_of_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>

Get any_of as a slice of QuestionPropertiesAnyOfTermEnums

This returns None if

  • There is no value present
  • There is only one value present
pub fn set_many_any_of_base_boxes<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
where T: TryInto<BaseBox>,

Set any_of from a vec of items that can be converted into BaseBoxs

pub fn delete_any_of(&mut self) -> &mut Self

Set the any_of field to None