Flag

Struct Flag 

pub struct Flag {
    pub kind: FlagType,
    pub flag_props: FlagProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}
Indicates that the actor is “flagging” the object.

Flagging is defined in the sense common to many social platforms as reporting content as being inappropriate for any number of reasons.

Fields

kind: FlagTypeflag_props: FlagProperties

Adds all valid flag properties to this struct

object_props: ObjectProperties

Adds all valid object properties to this struct

activity_props: ActivityProperties

Adds all valid activity properties to this struct

Implementations

Source

impl Flag

pub fn full() -> Ext<Flag, ApObjectProperties>

Generate a fully extended type

This effect can be achieved with Self::new().extend(SomeExtension::default())

Source

impl Flag

pub fn new() -> Self

Create from default