pub struct Update {
pub kind: UpdateType,
pub update_props: UpdateProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Expand description
Indicates that the actor has updated the object.
Note, however, that this vocabulary does not define a mechanism for describing the actual set of modifications made to object.
The target and origin typically have no defined meaning.
Fields
kind: UpdateTypeupdate_props: UpdatePropertiesAdds all valid update properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct
Implementations