Module collection

Module collection 

Namespace for Collection types

Modules

kind
Namespace for Unit Structs that serialize to strings
properties
Namespace for properties of standard collection types

Structs

CollectionBox
A wrapper type around a generic Collection
CollectionPageBox
A wrapper type around a generic CollectionPage
OrderedCollection
A subtype of Collection in which members of the logical collection are assumed to always be strictly ordered.
OrderedCollectionPage
Used to represent ordered subsets of items from an OrderedCollection.
UnorderedCollection
The default Collection type.
UnorderedCollectionPage
Used to represent distinct subsets of items from a Collection.

Traits

Collection
A Collection is a subtype of Object that represents ordered or unordered sets of Object or Link instances.
CollectionPage
Used to represent distinct subsets of items from a Collection.