Ext

Struct Ext 

pub struct Ext<T, U> {
    pub base: T,
    pub extension: U,
}
Defines an extension to an activitystreams object or link

This type provides two fields, the first field, base, should always the be base ActivityStreams type. As long as base implements an ActivityStreams trait, Ext will also.

For example, the type Ext<Video, HashMap<String, String>> will implement the Object trait, because Video implements that trait.

Additionally, AsRef and AsMut have been implemented for Ext. If type type Ext<Ext<Follow, SomeTime>, AnotherType> exists, that will implement AsRef<ActivityProperties> just like the innermost Follow.

Usage:

use activitystreams::object::Video;

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let mut video = Video::full();

    // AsMut works even though this is an Ext<Video, ApObjectProperties>
    video
        .as_mut()
        .set_id("https://example.com")?;

    // set information on the extension
    video
        .extension
        .set_source_xsd_any_uri("https://example.com")?;

    Ok(())
}

Fields

base: T

The ActivityStreams base type, or another extension containing one

extension: U

The extension being applied to the type