pub struct LinkBox(/* private fields */);Expand description
A wrapper type around a generic Link
Implementations
Sourceimpl LinkBox
impl LinkBox
Sourcepub fn from_concrete<T>(t: T) -> Result<Self, Error>
pub fn from_concrete<T>(t: T) -> Result<Self, Error>
Coerce a concrete type into this wrapper type
This is done automatically via TryFrom in proprties setter methods
Sourcepub fn into_concrete<T>(self) -> Result<T, Error>where
T: Link + DeserializeOwned,
pub fn into_concrete<T>(self) -> Result<T, Error>where
T: Link + DeserializeOwned,
Attempt to deserialize the wrapper type to a concrete type
Before this method is called, the type should be verified via the kind or
is_kind methods