XsdString

Struct XsdString 

pub struct XsdString(/* private fields */);
A string type that conforms to the xsd:string specification.

TODO: Escape < and & when converting

The type xsd:string represents a character string that may contain any Unicode character allowed by XML. Certain characters, namely the “less than” symbol (<) and the ampersand (&), must be escaped (using the entities < and &, respectively) when used in strings in XML instances.

The xsd:string type has a whiteSpace facet of preserve, which means that all whitespace characters (spaces, tabs, carriage returns, and line feeds) are preserved by the processor. This is in contrast to two types derived from it: normalizedString, and token.

Implementations

Source

impl XsdString

pub fn from_string(s: String) -> Self

Get an XsdString from a String

pub fn as_str(&self) -> &str

Borrow an &str from an XsdString

pub fn into_string(self) -> String

Consume the XsdString and get a String