pub struct ActorAndObjectProperties {
pub actor: ActorAndObjectPropertiesActorEnum,
pub object: ActorAndObjectPropertiesObjectEnum,
}Expand description
Struct with actor and object properties
Fields
actor: ActorAndObjectPropertiesActorEnumDescribes one or more entities that either performed or are expected to perform the activity.
Any single activity can have multiple actors. The actor MAY be specified using an indirect Link.
- Range:
Object|Link - Functional: false
object: ActorAndObjectPropertiesObjectEnumWhen used within an Activity, describes the direct object of the activity.
For instance, in the activity “John added a movie to his wishlist”, the object of the activity is the movie added.
- Range:
Object|Link - Functional: false
Implementations
Sourceimpl ActorAndObjectProperties
impl ActorAndObjectProperties
Sourcepub fn get_actor_xsd_any_uri(&self) -> Option<&XsdAnyUri>
pub fn get_actor_xsd_any_uri(&self) -> Option<&XsdAnyUri>
Get the actor as a XsdAnyUri
This returns None if
- There is more than one value present
- The requested type is not the stored type
Sourcepub fn set_actor_xsd_any_uri<T>(
&mut self,
item: T,
) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
pub fn set_actor_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
Set actor with a value that can be converted into XsdAnyUri
Sourcepub fn get_many_actor_xsd_any_uris(
&self,
) -> Option<impl Iterator<Item = &XsdAnyUri>>
pub fn get_many_actor_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>
Get actor as a vec of &XsdAnyUris
This returns None if
- There is only one value present
The returned vec will be empty if no values match the requested type, but values are present.
Sourcepub fn set_many_actor_xsd_any_uris<T>(
&mut self,
item: Vec<T>,
) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
pub fn set_many_actor_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
Set actor from a vec of items that can be converted into XsdAnyUris
Sourcepub fn get_actor_base_box(&self) -> Option<&BaseBox>
pub fn get_actor_base_box(&self) -> Option<&BaseBox>
Get the actor as a BaseBox
This returns None if
- There is more than one value present
- The requested type is not the stored type
Sourcepub fn set_actor_base_box<T>(
&mut self,
item: T,
) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
pub fn set_actor_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
Set actor with a value that can be converted into BaseBox
Sourcepub fn get_many_actor_base_boxes(
&self,
) -> Option<impl Iterator<Item = &BaseBox>>
pub fn get_many_actor_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>
Get actor as a vec of &BaseBoxs
This returns None if
- There is only one value present
The returned vec will be empty if no values match the requested type, but values are present.
Sourcepub fn set_many_actor_base_boxes<T>(
&mut self,
item: Vec<T>,
) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
pub fn set_many_actor_base_boxes<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
Set actor from a vec of items that can be converted into BaseBoxs
Sourcepub fn get_object_xsd_any_uri(&self) -> Option<&XsdAnyUri>
pub fn get_object_xsd_any_uri(&self) -> Option<&XsdAnyUri>
Get the object as a XsdAnyUri
This returns None if
- There is more than one value present
- The requested type is not the stored type
Sourcepub fn set_object_xsd_any_uri<T>(
&mut self,
item: T,
) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
pub fn set_object_xsd_any_uri<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
Set object with a value that can be converted into XsdAnyUri
Sourcepub fn get_many_object_xsd_any_uris(
&self,
) -> Option<impl Iterator<Item = &XsdAnyUri>>
pub fn get_many_object_xsd_any_uris( &self, ) -> Option<impl Iterator<Item = &XsdAnyUri>>
Get object as a vec of &XsdAnyUris
This returns None if
- There is only one value present
The returned vec will be empty if no values match the requested type, but values are present.
Sourcepub fn set_many_object_xsd_any_uris<T>(
&mut self,
item: Vec<T>,
) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
pub fn set_many_object_xsd_any_uris<T>( &mut self, item: Vec<T>, ) -> Result<&mut Self, <T as TryInto<XsdAnyUri>>::Error>
Set object from a vec of items that can be converted into XsdAnyUris
Sourcepub fn get_object_base_box(&self) -> Option<&BaseBox>
pub fn get_object_base_box(&self) -> Option<&BaseBox>
Get the object as a BaseBox
This returns None if
- There is more than one value present
- The requested type is not the stored type
Sourcepub fn set_object_base_box<T>(
&mut self,
item: T,
) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
pub fn set_object_base_box<T>( &mut self, item: T, ) -> Result<&mut Self, <T as TryInto<BaseBox>>::Error>
Set object with a value that can be converted into BaseBox
Sourcepub fn get_many_object_base_boxes(
&self,
) -> Option<impl Iterator<Item = &BaseBox>>
pub fn get_many_object_base_boxes( &self, ) -> Option<impl Iterator<Item = &BaseBox>>
Get object as a vec of &BaseBoxs
This returns None if
- There is only one value present
The returned vec will be empty if no values match the requested type, but values are present.