pub struct Flag {
pub kind: FlagType,
pub flag_props: FlagProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Expand description
Indicates that the actor is “flagging” the object.
Flagging is defined in the sense common to many social platforms as reporting content as being inappropriate for any number of reasons.
Fields
kind: FlagTypeflag_props: FlagPropertiesAdds all valid flag properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct
Implementations