pub struct XsdString(/* private fields */);Expand description
A string type that conforms to the xsd:string specification.
TODO: Escape < and & when converting
The type xsd:string represents a character string that may contain any Unicode character allowed by XML. Certain characters, namely the “less than” symbol (<) and the ampersand (&), must be escaped (using the entities < and &, respectively) when used in strings in XML instances.
The xsd:string type has a whiteSpace facet of preserve, which means that all whitespace characters (spaces, tabs, carriage returns, and line feeds) are preserved by the processor. This is in contrast to two types derived from it: normalizedString, and token.
Implementations